//! Textium is a small library that wires Rusttype up to Glium.

extern crate rusttype;
#[macro_use]
extern crate glium;

mod error;
mod texture;
mod geometry;
mod rasterizer;
mod packer;

use std::iter::Iterator;
use std::collections::HashMap;
use glium::backend::Facade;
use glium::texture::Texture2d;

pub use error::Error;
pub use geometry::Rect;
pub use rasterizer::Font;

/// Information used to render a glyph in a font.
#[derive(Debug)]
pub struct GlyphMetadata {
    /// Bounding box in the packed texture
    bounding_box: Rect<usize>,
    /// Scale that the character was rendered at
    scale: f32,

    /// Distance between the bottom of the glyph and the baseline, in ems.
    // baseline_distance: f32,

    /// Distance to advance in layout after this character
    advance_width: f32,

    /// Horizontal offset between glyph origin and leftmost point of the glyph
    left_bearing: f32,
}

pub struct FontAtlas {
    glyph_data: HashMap<char, GlyphMetadata>
}

pub struct FontTexture {
    /// The GPU texture of packed glyphs.
    texture: Texture2d,

    /// Atlas describing where glyphs are.
    atlas: FontAtlas,
}

